from setuptools import setup

setup(name='fbpageplc',
      version='0.2',
      description='Fetch posts, likes, comments of a public facebook page.',
      url='https://github.com/akash0824/fbpageplc',
      author='akash0824',
      author_email='akashkumar0824@gmail.com',
      #license='MIT',
      packages=['fbpageplc'],
      zip_safe=False)